@@ -15,23 +15,35 @@ def generate_test_array(n):
     ]
 
 
-def generate_test_array_non_null(n):
-    return [six.text_type(x) + six.text_type(x) + six.text_type(x) for x in range(n)]
-
-
-class TimeSuiteNonNull:
+class TimeSuiteText:
     def setup(self):
-        array = generate_test_array_non_null(2 ** 17)
+        array = [
+            ("a" * 50 + "b" if i % 2 == 0 else "c") * 5 + str(i) for i in range(2 ** 16)
+        ]
+        self.pattern = "a" * 30 + "b"
+
         self.df = pd.DataFrame({"str": array})
         self.df_ext = pd.DataFrame(
             {"str": fr.FletcherChunkedArray(pa.array(array, pa.string()))}
         )
 
+    def time_count_no_regex(self):
+        self.df["str"].str.count(self.pattern)
+
+    def time_count_no_regex_ext(self):
+        self.df_ext["str"].text.count(self.pattern, regex=False)
+
     def time_contains_no_regex(self):
-        self.df["str"].str.contains("0", regex=False)
+        self.df["str"].str.contains(self.pattern, regex=False)
 
     def time_contains_no_regex_ext(self):
-        self.df_ext["str"].text.contains("0", regex=False)
+        self.df_ext["str"].text.contains(self.pattern, regex=False)
+
+    def time_replace_no_regex(self):
+        self.df["str"].str.replace(self.pattern, "bc")
+
+    def time_replace_no_regex_ext(self):
+        self.df_ext["str"].text.count(self.pattern, "bc", regex=False)
 
 
 class TimeSuite:
@@ -73,12 +85,12 @@ class TimeSuite:
         self.df_ext["str"].text.zfill(10)
 
     def time_contains_no_regex(self):
-        self.df["str"].str.contains("0", regex=False)
+        self.df["str"].str.contains("1012102", regex=False)
 
     def time_contains_no_regex_ext(self):
-        self.df_ext["str"].text.contains("0", regex=False)
+        self.df_ext["str"].text.contains("1012102", regex=False)
 
-    def time_contains_no_regex_ignore_cast(self):
+    def time_contains_no_regex_ignore_case(self):
         self.df["str"].str.contains("0", regex=False, case=False)
 
     def time_contains_no_regex_ignore_case_ext(self):
@@ -102,6 +114,18 @@ class TimeSuite:
     def time_concat_ext(self):
         pd.concat([self.df_ext["str"]] * 2)
 
+    def time_count_no_regex(self):
+        self.df["str"].str.count("001")
+
+    def time_count_no_regex_ext(self):
+        self.df_ext["str"].text.count("001", regex=False)
+
+    def time_replace_no_regex(self):
+        self.df["str"].str.replace("001", "23")
+
+    def time_replace_no_regex_ext(self):
+        self.df_ext["str"].text.count("001", "23", regex=False)
+
 
 class Indexing(object):
     # index and value have diverse values, disable type checks for them
